@@ -1,4 +1,4 @@
-#' Plot of mave object
+#' Plot of mave or mave.dim object
 #'
 #' Plot the scatterplot of given dimension directions and reponse variables.
 #' @aliases plot.mave
@@ -8,6 +8,7 @@
 #' @param dim the dimension
 #' @param plot.method the method for plotting scatter plot. The default is 'pairs'
 #' @param ... arguments passed to the plot.method.
+#' @seealso \code{\link{mave}} for computing the dimension reduction space
 #' @examples
 #' x = matrix(rnorm(2000),400,5)
 #' beta1 = as.matrix(c(1,1,0,0,0))
@@ -20,12 +21,13 @@
 #' plot(dr.dim)
 #' @export
 #' @method plot mave
+#' @method plot mave.dim
 
 
 
 plot.mave<-function(x,dim=4,plot.method=pairs,...){
   dr <- x
-  dir <- mave.dir(dr,dim)
+  dir <- coef.mave(dr,dim)
   if(dr$call[[1]]=='mave'){
     y.name=all.vars(dr$call)[1]
   }
@@ -41,9 +43,9 @@ plot.mave<-function(x,dim=4,plot.method=pairs,...){
 plot.mave.dim<-function(x,dim='dim.min',plot.method=pairs,...){
   dr.dim <- x
   if(dim=='dim.min'){
-    dir <- mave.dir(dr.dim)
+    dir <- coef.mave.dim(dr.dim)
   }else{
-    dir <- mave.dir(dr.dim,dim)
+    dir <- coef.mave(dr.dim,dim)
   }
 
   if(dr.dim$call[[1]]=='mave'){
